@@ -27,13 +27,8 @@ from .core import CapabilityWalker, ConfigSpace
 from .msix import MSIXCapabilityHandler
 from .patches import PatchEngine
 from .rules import RuleEngine
-from .types import (
-    CapabilityInfo,
-    CapabilityType,
-    EmulationCategory,
-    PatchInfo,
-    PruningAction,
-)
+from .types import (CapabilityInfo, CapabilityType, EmulationCategory,
+                    PatchInfo, PruningAction)
 
 logger = logging.getLogger(__name__)
 
@@ -1666,7 +1661,8 @@ class CapabilityProcessor:
 
     def _create_generic_removal_patches(self, cap_info: CapabilityInfo) -> List:
         """Create generic patches to remove a capability from the capability chain."""
-        from .constants import PCI_CAP_NEXT_PTR_OFFSET, PCI_CAPABILITIES_POINTER
+        from .constants import (PCI_CAP_NEXT_PTR_OFFSET,
+                                PCI_CAPABILITIES_POINTER)
 
         patches = []
 
