@@ -354,22 +354,23 @@ class AdvancedSVGenerator:
         try:
             # Add missing template variables for PCILeech modules
             enhanced_context = template_context.copy()
-            
+
             # Extract device config for easier access
             device_config = template_context.get("device_config", {})
-            
+
             # Generate header comment for SystemVerilog files
             try:
                 from ..string_utils import generate_sv_header_comment
+
                 header = generate_sv_header_comment(
                     "PCILeech SystemVerilog Module",
                     generator="PCILeechFWGenerator - SystemVerilog Generation",
                     device_type="PCIe Device Controller",
-                    features="PCILeech integration, MSI-X support, BAR controller"
+                    features="PCILeech integration, MSI-X support, BAR controller",
                 )
             except ImportError:
                 header = "// PCILeech SystemVerilog Module\n// Generated by PCILeechFWGenerator"
-            
+
             # Create device object for template compatibility
             device_info = {
                 "vendor_id": device_config.get("vendor_id", "0000"),
@@ -379,36 +380,51 @@ class AdvancedSVGenerator:
                 "class_code": device_config.get("class_code", "020000"),
                 "revision_id": device_config.get("revision_id", "01"),
             }
-            
-            enhanced_context.update({
-                "header": header,  # Add header for template
-                "device": device_info,
-                "config_space": {
+
+            enhanced_context.update(
+                {
+                    "header": header,  # Add header for template
+                    "device": device_info,
+                    "config_space": {
+                        "vendor_id": device_config.get("vendor_id", "0000"),
+                        "device_id": device_config.get("device_id", "0000"),
+                        "class_code": device_config.get("class_code", "020000"),
+                        "revision_id": device_config.get("revision_id", "01"),
+                    },
+                    "enable_custom_config": True,
+                    "enable_scatter_gather": getattr(
+                        self.device_config, "enable_dma", True
+                    ),
+                    "enable_interrupt": template_context.get(
+                        "interrupt_config", {}
+                    ).get("vectors", 0)
+                    > 0,
+                    "enable_clock_crossing": True,
+                    "enable_performance_counters": getattr(
+                        self.perf_config, "enable_transaction_counters", True
+                    ),
+                    "enable_error_detection": getattr(
+                        self.error_config, "enable_ecc", True
+                    ),
+                    "fifo_type": "block_ram",
+                    "fifo_depth": 512,
+                    "data_width": 128,
+                    "fpga_family": "artix7",
                     "vendor_id": device_config.get("vendor_id", "0000"),
                     "device_id": device_config.get("device_id", "0000"),
-                    "class_code": device_config.get("class_code", "020000"),
-                    "revision_id": device_config.get("revision_id", "01"),
-                },
-                "enable_custom_config": True,
-                "enable_scatter_gather": getattr(self.device_config, "enable_dma", True),
-                "enable_interrupt": template_context.get("interrupt_config", {}).get("vectors", 0) > 0,
-                "enable_clock_crossing": True,
-                "enable_performance_counters": getattr(self.perf_config, "enable_transaction_counters", True),
-                "enable_error_detection": getattr(self.error_config, "enable_ecc", True),
-                "fifo_type": "block_ram",
-                "fifo_depth": 512,
-                "data_width": 128,
-                "fpga_family": "artix7",
-                "vendor_id": device_config.get("vendor_id", "0000"),
-                "device_id": device_config.get("device_id", "0000"),
-                "vendor_id_hex": device_config.get("vendor_id", "0000"),
-                "device_id_hex": device_config.get("device_id", "0000"),
-                "device_specific_config": {},
-            })
-            
+                    "vendor_id_hex": device_config.get("vendor_id", "0000"),
+                    "device_id_hex": device_config.get("device_id", "0000"),
+                    "device_specific_config": {},
+                }
+            )
+
             # Add enable_advanced_features to device_config section if it doesn't exist
-            if "device_config" in enhanced_context and isinstance(enhanced_context["device_config"], dict):
-                enhanced_context["device_config"]["enable_advanced_features"] = getattr(self.error_config, "enable_ecc", True)
+            if "device_config" in enhanced_context and isinstance(
+                enhanced_context["device_config"], dict
+            ):
+                enhanced_context["device_config"]["enable_advanced_features"] = getattr(
+                    self.error_config, "enable_ecc", True
+                )
 
             # Generate PCILeech TLP BAR controller
             modules["pcileech_tlps128_bar_controller"] = self.renderer.render_template(
@@ -419,7 +435,7 @@ class AdvancedSVGenerator:
             modules["pcileech_fifo"] = self.renderer.render_template(
                 "systemverilog/pcileech_fifo.sv.j2", enhanced_context
             )
-            
+
             # Generate top-level wrapper (CRITICAL for Vivado top module)
             try:
                 modules["top_level_wrapper"] = self.renderer.render_template(
@@ -435,10 +451,12 @@ class AdvancedSVGenerator:
                     log_warning_safe(
                         self.logger,
                         "Failed to generate top_level_wrapper from both paths: {error}",
-                        error=str(e)
+                        error=str(e),
                     )
                     # Generate a basic top-level wrapper as fallback
-                    modules["top_level_wrapper"] = self._generate_basic_top_wrapper(enhanced_context)
+                    modules["top_level_wrapper"] = self._generate_basic_top_wrapper(
+                        enhanced_context
+                    )
 
             # Generate configuration space COE file
             modules["pcileech_cfgspace.coe"] = self.renderer.render_template(
@@ -994,9 +1012,12 @@ class AdvancedSVGenerator:
         device_config = context.get("device_config", {})
         vendor_id = device_config.get("vendor_id", "0000")
         device_id = device_config.get("device_id", "0000")
-        
-        header = context.get("header", "// PCILeech Top-Level Wrapper\n// Generated by PCILeechFWGenerator")
-        
+
+        header = context.get(
+            "header",
+            "// PCILeech Top-Level Wrapper\n// Generated by PCILeechFWGenerator",
+        )
+
         return f"""// PCILeech Top-Level Wrapper
 // Generated for device: {vendor_id}:{device_id}
 
