@@ -381,8 +381,7 @@ class ConfigManager:
                     "name": "Network Device Standard",
                     "description": "Standard configuration for network devices",
                     "config": BuildConfiguration(
-                        board_type="75t",
-                        device_type="network",
+                        board_type="pcileech_35t325_x1",
                         advanced_sv=True,
                         enable_variance=True,
                         behavior_profiling=False,
